@@ -33,7 +33,7 @@ extern char* ini_file;
 #define SETTING_ADVANCED_MODE_FORMAT        "ShowAdvancedFormatOptions"
 #define SETTING_COMM_CHECK                  "CommCheck64"
 #define SETTING_DEFAULT_THREAD_PRIORITY     "DefaultThreadPriority"
-#define SETTING_DISABLE_DARK_MODE           "DisableDarkMode"
+#define SETTING_DARK_MODE                   "DarkMode"
 #define SETTING_DISABLE_FAKE_DRIVES_CHECK   "DisableFakeDrivesCheck"
 #define SETTING_DISABLE_LGP                 "DisableLGP"
 #define SETTING_DISABLE_RUFUS_MBR           "DisableRufusMBR"
